Hotel Booking Calendar Challenge

# 🏨 Hotel Booking Calendar Challenge

Select your check-in and check-out dates for the best rates

Grand Plaza Hotel
★★★★☆
4.2
📍 Downtown, Business District
Free WiFi Pool Gym Restaurant Parking
Guests
Rooms
Room Type
Minimum Stay: This hotel requires a minimum stay of 2 nights during weekends and 1 night during weekdays.

## Select Your Stay Dates

Sun
Mon
Tue
Wed
Thu
Fri
Sat
Sun
Mon
Tue
Wed
Thu
Fri
Sat
Available
Limited Availability
Unavailable
Check-in
Check-out
Standard Rate
$120/night
Free cancellation • No prepayment needed
Advance Purchase
$99/night
Save 17% • Non-refundable
Package Deal
$140/night
Includes breakfast • Free parking

### Booking Summary

Check-in: -
Check-out: -
Nights: -
Room rate: -
Taxes & fees: -
Total: -
Reservation Confirmed! Your hotel booking has been confirmed. You will receive a confirmation email shortly.